% This script generates figures for F and T contrasts contained in
% 2ndlev_contrasts_TF.zip
%
% You will need to install SPM to run this script
% http://www.fil.ion.ucl.ac.uk/spm/software/
% 
% The figures correspond to Fig. 3 and S2 in the manuscript
% 
% Copyright: Ryszard Auksztulewicz ryszard.auksztulewicz@psych.ox.ac.uk
% 26-05-2017

figure;
epoch={'cue_prediction' 'target_PE'};
regions={'A1' 'MTG' 'TPJ' 'V1'};
for i=1:length(epoch)
    for j=1:length(regions)
        subplot(2,4,(i-1)*4+j)
        [y,xyz]=spm_read_vols(spm_vol(strcat('2ndlev_',regions{j},'_',epoch{i},'_Fcontrast.nii')));
        imagesc(y(end:-1:1,:),[0 8])
        title(strcat('F contrast:',regions{j},':',epoch{i}),'interpreter','none')
        set(gca,'xtick',1:10:38,'xticklabel',-.25:.2:.5)
        xlabel('time (s)')
        set(gca,'ytick',1:10:41,'yticklabel',48:-10:8)
        ylabel('freq (Hz)')
        hold on
        try [ym,xyz]=spm_read_vols(spm_vol(strcat('2ndlev_',regions{j},'_',epoch{i},'_FWEsig_cluster.nii')));
            h=imagesc(cat(3,ones(size(ym)),ones(size(ym)),ones(size(ym))));
            set(h,'AlphaData',~ym(end:-1:1,:)*.5);
            h2=imagesc(cat(3,zeros(size(ym)),zeros(size(ym)),zeros(size(ym))));
            set(h2,'AlphaData',edge(ym(end:-1:1,:),'log'));
        catch
            h=imagesc(cat(3,ones(size(ym)),ones(size(ym)),ones(size(ym))));
            set(h,'AlphaData',ones(size(y))*.5);
        end
    end
end

figure;
files=dir('*Tcontrast*.nii');
for i=1:length(files)
    subplot(2,4,i)
    [y,xyz]=spm_read_vols(spm_vol(files(i).name));
    imagesc(y(end:-1:1,:),[-5 5])
    title(files(i).name(8:end-4),'interpreter','none')
    set(gca,'xtick',1:10:38,'xticklabel',-.25:.2:.5)
    xlabel('time (s)')
    set(gca,'ytick',1:10:41,'yticklabel',48:-10:8)
    ylabel('freq (Hz)')
    hold on
    try [ym,xyz]=spm_read_vols(spm_vol(strcat(files(i).name(1:strfind(files(i).name,'Tcontrast')-1),'FWEsig_cluster.nii')));
        h=imagesc(cat(3,ones(size(ym)),ones(size(ym)),ones(size(ym))));
        set(h,'AlphaData',~ym(end:-1:1,:)*.5);
        h2=imagesc(cat(3,zeros(size(ym)),zeros(size(ym)),zeros(size(ym))));
        set(h2,'AlphaData',edge(ym(end:-1:1,:),'log'));
    catch
        h=imagesc(cat(3,ones(size(ym)),ones(size(ym)),ones(size(ym))));
        set(h,'AlphaData',ones(size(y))*.5);
    end
end

